@@ -53,7 +53,7 @@ def run(args, parser):
         elif args.action == "local":
             f.local(args.team)
         elif args.action == "create":
-            f.create_dataset(args.dataset_name, args.team)
+            f.create_dataset(args.dataset)
         elif args.action == "path":
             path = f.path(args.dataset)
             if path:
@@ -75,7 +75,7 @@ def run(args, parser):
         elif args.action == "releases":
             f.dataset_list_releases(args.dataset)
         elif args.action == "pull":
-            f.pull_dataset(args.dataset, args.only_annotations, args.folders)
+            f.pull_dataset(args.dataset, args.only_annotations, args.folders, args.video_frames)
         elif args.action == "import":
             f.dataset_import(args.dataset, args.format, args.files)
         elif args.action == "convert":
