@@ -3,10 +3,10 @@ from typing import List, Optional
 
 import numpy as np
 import torch
+from upolygon import draw_polygon
 
 from darwin.cli_functions import _error, _load_client
 from darwin.dataset.identifier import DatasetIdentifier
-from upolygon import draw_polygon
 
 
 def convert_segmentation_to_mask(segmentations: List[List[float]], height: int, width: int):
@@ -63,7 +63,7 @@ def detectron2_register_dataset(
         Evaluator to be used in the val and test sets
     """
     try:
-        from detectron2.data import MetadataCatalog, DatasetCatalog
+        from detectron2.data import DatasetCatalog, MetadataCatalog
     except ImportError:
         print("Detectron2 not found.")
         sys.exit(1)
